@@ -11,9 +11,9 @@ THUMBNAIL_LOG_HANDLER = {
     'class': 'sorl.thumbnail.log.ThumbnailLogHandler',
     'level': 'ERROR',
 }
-THUMBNAIL_KVSTORE = 'thumbnail_tests.kvstore.TestKVStore'
-THUMBNAIL_STORAGE = 'thumbnail_tests.storage.TestStorage'
-DEFAULT_FILE_STORAGE = 'thumbnail_tests.storage.TestStorage'
+THUMBNAIL_KVSTORE = 'tests.thumbnail_tests.kvstore.TestKVStore'
+THUMBNAIL_STORAGE = 'tests.thumbnail_tests.storage.TestStorage'
+DEFAULT_FILE_STORAGE = 'tests.thumbnail_tests.storage.TestStorage'
 ADMINS = (
     ('Sorl', 'thumbnail@sorl.net'),
 )
@@ -25,22 +25,19 @@ DATABASES = {
 }
 MEDIA_ROOT = pjoin(PROJ_ROOT, 'media')
 MEDIA_URL = '/media/'
-ROOT_URLCONF = 'thumbnail_tests.urls'
-if django.VERSION < (1, 6):
-    INSTALLED_APPS = (
-        'thumbnail',
-        'thumbnail_tests',
-    )
-else:
-    INSTALLED_APPS = (
-        'sorl.thumbnail',
-        'tests.thumbnail_tests',
-    )
-
-TEMPLATE_CONTEXT_PROCESSORS = (
-    "django.core.context_processors.request",
+ROOT_URLCONF = 'tests.thumbnail_tests.urls'
+INSTALLED_APPS = (
+    'django.contrib.auth',
+    'django.contrib.contenttypes',
+    'sorl.thumbnail',
+    'tests.thumbnail_tests',
 )
-MIDDLEWARE_CLASSES = (
+
+TEMPLATES = [{
+    'BACKEND': 'django.template.backends.django.DjangoTemplates',
+    'APP_DIRS': True,
+}]
+MIDDLEWARE = (
     'django.contrib.sessions.middleware.SessionMiddleware',
     'django.middleware.common.CommonMiddleware',
     'django.middleware.csrf.CsrfViewMiddleware',
@@ -48,3 +45,4 @@ MIDDLEWARE_CLASSES = (
     'django.contrib.messages.middleware.MessageMiddleware',
     'django.middleware.clickjacking.XFrameOptionsMiddleware',
 )
+THUMBNAIL_REDIS_SSL = False
