@@ -1,6 +1,5 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
 import os
+import platform
 import unittest
 from subprocess import Popen, PIPE
 
@@ -18,7 +17,6 @@ from sorl.thumbnail.parsers import parse_geometry
 from sorl.thumbnail.templatetags.thumbnail import margin
 from sorl.thumbnail.engines.pil_engine import Engine as PILEngine
 from .models import Item
-from .compat import is_osx
 from .utils import BaseTestCase
 
 
@@ -168,7 +166,7 @@ class SimpleTestCase(BaseTestCase):
             'tests.thumbnail_tests.storage.TestStorage',
         )
 
-    @unittest.skipIf(is_osx(), 'quality is saved a different way on os x')
+    @unittest.skipIf(platform.system() == "Darwin", 'quality is saved a different way on os x')
     def test_quality(self):
         im = ImageFile(Item.objects.get(image='500x500.jpg').image)
         th = self.BACKEND.get_thumbnail(im, '100x100', quality=50)
@@ -185,6 +183,12 @@ class SimpleTestCase(BaseTestCase):
         img = Image.open(th.storage.path(th.name))
         self.assertTrue(self.is_transparent(img))
 
+    def test_transparency_gif_to_jpeg(self):
+        path = 'data/animation_w_transparency.gif'
+        th = self.BACKEND.get_thumbnail(path, '11x11', format='JPEG')
+        img = Image.open(th.storage.path(th.name))
+        self.assertFalse(self.is_transparent(img))
+
     def test_image_file_deserialize(self):
         im = ImageFile(Item.objects.get(image='500x500.jpg').image)
         default.kvstore.set(im)
@@ -241,7 +245,6 @@ class SimpleTestCase(BaseTestCase):
         self.assertEqual(t.x, 100)
         self.assertEqual(t.y, 100)
 
-
     def test_falsey_file_argument(self):
         with self.assertRaises(ValueError):
             self.BACKEND.get_thumbnail('', '100x100')
@@ -251,7 +254,7 @@ class SimpleTestCase(BaseTestCase):
 
 class CropTestCase(BaseTestCase):
     def setUp(self):
-        super(CropTestCase, self).setUp()
+        super().setUp()
 
         # portrait
         name = 'portrait.jpg'
@@ -341,14 +344,20 @@ class CropTestCase(BaseTestCase):
             for x, y in coords:
                 self.assertEqual(0 <= mean_pixel(x, y) < 5, True)
 
-    def test_smart_crop(self):
-        # TODO: Complete test for smart crop
-        self.BACKEND.get_thumbnail('32x32', 'data/white_border.jpg', crop='smart')
-
     @unittest.skipIf(
         'pil_engine' not in settings.THUMBNAIL_ENGINE,
         'the other engines fail this test',
     )
+    def test_smart_crop(self):
+        th = self.BACKEND.get_thumbnail('data/white_border.jpg', '32x32', crop='smart')
+        self.assertEqual(th.x, 32)
+        self.assertEqual(th.y, 32)
+
+        engine = PILEngine()
+        im = engine.get_image(th)
+        self.assertEqual(im.size[0], 32)
+        self.assertEqual(im.size[1], 32)
+
     def test_image_with_orientation(self):
         name = 'data/aspect_test.jpg'
         item, _ = Item.objects.get_or_create(image=name)
@@ -380,12 +389,157 @@ class CropTestCase(BaseTestCase):
         )
 
 
+# Only PIL has support for checking pixel color. convert and wand engines are both missing it,
+# so we cannot test for pixel color
+class CropBoxTestCase(BaseTestCase):
+    def setUp(self):
+        super().setUp()
+
+        # portrait
+        name = 'portrait.jpg'
+        fn = os.path.join(settings.MEDIA_ROOT, name)
+        im = Image.new('L', (100, 200))
+        im.paste(255, (0, 0, 100, 100))
+        im.save(fn)
+        self.portrait = ImageFile(Item.objects.get_or_create(image=name)[0].image)
+        self.KVSTORE.delete(self.portrait)
+
+        # landscape
+        name = 'landscape.jpg'
+        fn = os.path.join(settings.MEDIA_ROOT, name)
+        im = Image.new('L', (200, 100))
+        im.paste(255, (0, 0, 100, 100))
+        im.save(fn)
+        self.landscape = ImageFile(Item.objects.get_or_create(image=name)[0].image)
+        self.KVSTORE.delete(self.landscape)
+
+    @unittest.skipIf(
+        'pil_engine' not in settings.THUMBNAIL_ENGINE,
+        'the other engines fail this test',
+    )
+    def PIL_test_portrait_crop(self):
+        def mean_pixel(x, y):
+            values = im.getpixel((x, y))
+            if not isinstance(values, (tuple, list)):
+                values = [values]
+            return sum(values) / len(values)
+
+        # Center Crop
+        th = self.BACKEND.get_thumbnail(self.portrait, '100x100', cropbox="0,50,100,150")
+        engine = PILEngine()
+        im = engine.get_image(th)
+
+        # Top half should be color, bottom not
+        self.assertEqual(mean_pixel(0, 0), 255)
+        self.assertEqual(mean_pixel(50, 0), 255)
+        self.assertEqual(mean_pixel(50, 45), 255)
+        self.assertEqual(mean_pixel(50, 55), 0)
+        self.assertEqual(mean_pixel(50, 99), 0)
+
+        # Top Crop
+        th = self.BACKEND.get_thumbnail(self.portrait, '100x100', cropbox="0,0,100,100")
+        engine = PILEngine()
+        im = engine.get_image(th)
+        for x in range(0, 99, 10):
+            for y in range(0, 99, 10):
+                self.assertEqual(250 < mean_pixel(x, y) <= 255, True)
+
+        # Bottom Crop
+        th = self.BACKEND.get_thumbnail(self.portrait, '100x100', cropbox="0,100,100,200")
+        engine = PILEngine()
+        im = engine.get_image(th)
+        for x in range(0, 99, 10):
+            for y in range(0, 99, 10):
+                self.assertEqual(0 <= mean_pixel(x, y) < 5, True)
+
+    @unittest.skipIf(
+        'pil_engine' not in settings.THUMBNAIL_ENGINE,
+        'the other engines fail this test',
+    )
+    def PIL_test_landscape_crop(self):
+
+        def mean_pixel(x, y):
+            values = im.getpixel((x, y))
+            if not isinstance(values, (tuple, list)):
+                values = [values]
+            return sum(values) / len(values)
+
+        # Center
+        th = self.BACKEND.get_thumbnail(self.landscape, '100x100', cropbox="50,0,150,100")
+        engine = PILEngine()
+        im = engine.get_image(th)
+
+        self.assertEqual(mean_pixel(0, 50), 255)
+        self.assertEqual(mean_pixel(45, 50), 255)
+        self.assertEqual(250 < mean_pixel(49, 50) <= 255, True)
+        self.assertEqual(mean_pixel(55, 50), 0)
+        self.assertEqual(mean_pixel(99, 50), 0)
+
+        # Left
+        th = self.BACKEND.get_thumbnail(self.landscape, '100x100', cropbox="0,0,100,100")
+        engine = PILEngine()
+        im = engine.get_image(th)
+        for x in range(0, 99, 10):
+            for y in range(0, 99, 10):
+                self.assertEqual(250 < mean_pixel(x, y) <= 255, True)
+
+        # Right
+        th = self.BACKEND.get_thumbnail(self.landscape, '100x100', cropbox="100,0,200,100")
+        engine = PILEngine()
+        im = engine.get_image(th)
+        coords = ((x, y) for y in range(0, 99, 10) for x in range(0, 99, 10))
+
+        for x, y in coords:
+            self.assertEqual(0 <= mean_pixel(x, y) < 5, True)
+
+    @unittest.skipIf(
+        'wand_engine' not in settings.THUMBNAIL_ENGINE,
+        'the other engines fail this test',
+    )
+    def wand_test_cropbox(self):
+        from sorl.thumbnail.engines.wand_engine import Engine as WandEngine
+        th = self.BACKEND.get_thumbnail(self.portrait, '100x100', cropbox="0,50,100,150")
+        engine = WandEngine()
+        im = engine.get_image(th)
+
+        # If the crop went well, then it should scale to 100x100 perfectly
+        self.assertEqual(im.width(100), 100)
+        self.assertEqual(im.height(100), 100)
+
+    @unittest.skipIf(
+        'pgmagick_engine' not in settings.THUMBNAIL_ENGINE,
+        'the other engines fail this test',
+    )
+    def pgmagick_test_cropbox(self):
+        from sorl.thumbnail.engines.pgmagick_engine import Engine as PgMagickEngine
+        th = self.BACKEND.get_thumbnail(self.portrait, '100x100', cropbox="0,50,100,150")
+        engine = PgMagickEngine()
+        im = engine.get_image(th)
+
+        # If the crop went well, then it should scale to 100x100 perfectly
+        self.assertEqual(im.width(100), 100)
+        self.assertEqual(im.height(100), 100)
+
+    @unittest.skipIf(
+        'convert_engine' not in settings.THUMBNAIL_ENGINE,
+        'the other engines fail this test',
+    )
+    def convert_test_cropbox(self):
+        from sorl.thumbnail.engines.convert_engine import Engine as ConvertEngine
+        th = self.BACKEND.get_thumbnail(self.portrait, '100x100', cropbox="0,50,100,150")
+        engine = ConvertEngine()
+        im = engine.get_image(th)
+
+        # If the crop went well, then it should scale to 100x100 perfectly
+        self.assertEqual(im["size"], (100, 100))
+
+
 class DummyTestCase(unittest.TestCase):
     def setUp(self):
         self.BACKEND = get_module_class(settings.THUMBNAIL_BACKEND)()
 
     def tearDown(self):
-        super(DummyTestCase, self).tearDown()
+        super().tearDown()
         settings.THUMBNAIL_ALTERNATIVE_RESOLUTIONS = []
 
     def test_dummy_tags(self):
